@@ -42,11 +42,7 @@ class Env(Base):
         self.port("8000")
         self.schema("http")
         self.api_version("api/v1beta1")
-        self.token("")
         self.api_key("")
-        self.domain = "timeplus.us.auth0.com"
-        self._max_token_refresh = 24
-        self._token_refresh = 0
 
         self._headers = CaseInsensitiveDict()
         self._headers["Accept"] = "application/json"
@@ -90,15 +86,6 @@ class Env(Base):
     def schema(self, *args):
         return self.prop("schema", *args)
 
-    def audience(self, *args):
-        return self.prop("audience", *args)
-
-    def client_id(self, *args):
-        return self.prop("client_id", *args)
-
-    def client_secret(self, *args):
-        return self.prop("client_secret", *args)
-
     def api_version(self, *args):
         return self.prop("api_version", *args)
 
@@ -108,12 +95,8 @@ class Env(Base):
     def headers(self):
         if self.api_key():  # check if key and id are not empty
             self._headers["X-Api-Key"] = self.api_key()
-        else:
-            self._headers["Authorization"] = f"Bearer {self.token()}"
-        return self._headers
 
-    def token(self, *args):
-        return self.prop("token", *args)
+        return self._headers
 
     def api_key(self, *args):
         return self.prop("api_key", *args)
@@ -144,41 +127,6 @@ class Env(Base):
         except Exception as e:
             raise e
 
-    def request_token(self):
-        url = f"https://{self.domain}/oauth/token"
-        self.logger().debug(f"request token from {url}")
-
-        try:
-            data = {
-                "client_id": self.client_id(),
-                "client_secret": self.client_secret(),
-                "audience": self.audience(),
-                "grant_type": "client_credentials",
-            }
-            self.logger().debug(f"request token data {data}")
-            headers = CaseInsensitiveDict()
-            headers["Content-Type"] = "application/json"
-            r = requests.post(url, json=data, headers=headers)
-            if r.status_code < 200 or r.status_code > 299:
-                err_msg = f"failed to request code due to {r.text}"
-                self._logger.error(err_msg)
-                raise TimeplusAPIError("post", r.status_code, err_msg)
-            else:
-                return r.json()
-        except Exception as e:
-            raise e
-
-    def refresh_token(self):
-        self._logger.info(f"refresh token {self._token_refresh}")
-        token = self.request_token()
-        self.token(token["access_token"])
-        self._logger.info(f"set token to {self.token()}")
-        self._token_refresh += 1
-        if self._token_refresh > self._max_token_refresh:
-            raise TimeplusAPIError("token_refresh", 0, "max refresh reached")
-
-        return self
-
     def logger(self):
         return self._logger
 
@@ -197,11 +145,7 @@ class Env(Base):
                 )
                 if r.status_code < 200 or r.status_code > 299:
                     err_msg = f"failed to send http post due to {r.text}"
-                    if r.status_code == 401:
-                        self.refresh_token()
-                        return self.http_post(url, data)
-                    else:
-                        raise TimeplusAPIError("post", r.status_code, err_msg)
+                    raise TimeplusAPIError("post", r.status_code, err_msg)
                 else:
                     return r
         except Exception as e:
@@ -220,11 +164,7 @@ class Env(Base):
                 )
                 if r.status_code < 200 or r.status_code > 299:
                     err_msg = f"failed to send http post due to {r.text}"
-                    if r.status_code == 401:
-                        self.refresh_token()
-                        return self.http_post_data(url, data)
-                    else:
-                        raise TimeplusAPIError("post", r.status_code, err_msg)
+                    raise TimeplusAPIError("post", r.status_code, err_msg)
                 else:
                     return r
         except Exception as e:
@@ -242,11 +182,7 @@ class Env(Base):
                 )
                 if r.status_code < 200 or r.status_code > 299:
                     err_msg = f"failed to send http get due to {r.text}"
-                    if r.status_code == 401:
-                        self.refresh_token()
-                        return self.http_get(url)
-                    else:
-                        raise TimeplusAPIError("get", r.status_code, err_msg)
+                    raise TimeplusAPIError("get", r.status_code, err_msg)
                 else:
                     return r.json()
         except Exception as e:
@@ -265,12 +201,7 @@ class Env(Base):
                 if r.status_code < 200 or r.status_code > 299:
                     err_msg = f"failed to send httpdelete due to {r.text}"
                     self._logger.error(err_msg)
-
-                    if r.status_code == 401:
-                        self.refresh_token()
-                        return self.http_delete(url)
-                    else:
-                        raise TimeplusAPIError("delete", r.status_code, err_msg)
+                    raise TimeplusAPIError("delete", r.status_code, err_msg)
                 else:
                     return
         except Exception as e:
